package net.wanji.utc.dto.twinspat;

import lombok.Data;

/**
 * 相位信息
 * 解释名词：
 *  相位是指在一个信号灯周期中，某一组特定方向的交通流获得通行权（如绿灯）的状态。
 *  “相位”就是信号灯在某个时间段内允许某些方向车辆通行的一种状态。
 *  “当前相位”是指当前正在运行的信号灯状态，决定了哪些方向可以通行、哪些需要等待。
 *
 */
@Data
public class Phase {
    private String id;             // 唯一值 phaseId + "_" + laneId
    private int phaseId;           // 相位ID [1-16], 控制一个灯组
    private int laneId;            // 车道编号
    private int state;             // 转向（灯组状态 [参考表E.3]）
    private int importDirect;      // 进口方向 [参考表E.2]
    private int turn;              // 车道转向
    private int light;             // 信号灯颜色 [0..8]
    private int limitEndTime;      // 信号灯倒计时, 单位：秒
    private String log;            // 经度
    private String lat;            // 纬度
    private float angle;           // 信号灯角度
}