package net.wanji.utc.util;

/**
 * 灯态车道转向映射器
 */
public class TurnDirectionMapper {

    // 定义映射关系，索引为源头转向值，值为目标转向值
    private static final int[] DIRECTION_MAP = {
        1,  // 源头值 0 -> 目标值 1（左转）
        2,  // 源头值 1 -> 目标值 2（直行）
        1,  // 源头值 2 -> 目标值 1（左转）
        5,  // 源头值 3 -> 目标值 5（直左）
        3,  // 源头值 4 -> 目标值 3（右转）
        6,  // 源头值 5 -> 目标值 6（直右）
        8,  // 源头值 6 -> 目标值 8（左右）
        7,  // 源头值 7 -> 目标值 7（左直右）
        4,  // 源头值 8 -> 目标值 4（掉头）
        10, // 源头值 9 -> 目标值 10（直行掉头）
        9,  // 源头值 10 -> 目标值 9（左转掉头）
        12, // 源头值 11 -> 目标值 12（左直掉头）
        11, // 源头值 12 -> 目标值 11（右转掉头）
        13, // 源头值 13 -> 目标值 13（直右掉头）
        15, // 源头值 14 -> 目标值 15（左右掉头）
        14  // 源头值 15 -> 目标值 14（左直右掉头）
    };

    /**
     * 转换源头转向值到目标转向值
     *
     * @param sourceValue 源头转向值 (0-15)
     * @return 目标转向值 (1-15)
     */
    public static int mapToTargetValue(int sourceValue) {
        if (sourceValue < 0 || sourceValue >= DIRECTION_MAP.length) {
            throw new IllegalArgumentException("非法源头转向值: " + sourceValue);
        }
        return DIRECTION_MAP[sourceValue];
    }

    public static void main(String[] args) {
        for (int i = 0; i < 16; i++) {
            System.out.println("源头值 " + i + " 映射的目标值为: " + mapToTargetValue(i));
        }
    }
}
